@@ -17,7 +17,7 @@ import shutil
 import subprocess
 import sys
 
-from PIL import Image, ImageFilter
+from PIL import Image, ImageFilter, UnidentifiedImageError
 from bs4 import BeautifulSoup
 import six
 from six.moves.urllib_parse import unquote, urlparse
@@ -29,7 +29,6 @@ from pelican import signals
 log = logging.getLogger(__name__)
 
 IMAGE_PROCESS_REGEX = re.compile("image-process-[-a-zA-Z0-9_]+")
-PELICAN_MAJOR_VERSION = int(pelican_version.split(".")[0])
 
 Path = collections.namedtuple("Path", ["base_url", "source", "base_path", "filename"])
 
@@ -46,8 +45,9 @@ class ExifTool(object):
     def start_exiftool():
         if shutil.which("exiftool") is None:
             log.warning(
-                "EXIF tags will not be copied because the exiftool program could not "
-                "be found. Please install exiftool and make sure it is in your path."
+                "[image_process] EXIF tags will not be copied because "
+                "the exiftool program could not be found. "
+                "Please install exiftool and make sure it is in your path."
             )
         else:
             ExifTool._instance = ExifTool()
@@ -110,7 +110,9 @@ class ExifTool(object):
             output += os.read(fd, ExifTool.block_size)
         exiftool_result = output.strip()[: -len(ExifTool.sentinel)]
         log.debug(
-            "image_process: exiftool result: {}".format(exiftool_result.decode("utf-8"))
+            "[image_process] exiftool result: {}".format(
+                exiftool_result.decode("utf-8")
+            )
         )
 
 
@@ -167,7 +169,7 @@ def resize(i, w, h):
     elif i.mode == "1":
         i = i.convert("L")
 
-    return i.resize((int(w), int(h)), Image.LANCZOS)
+    return i.resize((int(w), int(h)), Image.Resampling.LANCZOS)
 
 
 def scale(i, w, h, upscale, inside):
@@ -213,7 +215,7 @@ def scale(i, w, h, upscale, inside):
     elif i.mode == "1":
         i = i.convert("L")
 
-    return i.resize((int(scale * iw), int(scale * ih)), Image.LANCZOS)
+    return i.resize((int(scale * iw), int(scale * ih)), Image.Resampling.LANCZOS)
 
 
 def rotate(i, degrees):
@@ -223,7 +225,7 @@ def rotate(i, degrees):
         i = i.convert("L")
 
     # rotate does not support the LANCZOS filter (Pillow 2.7.0).
-    return i.rotate(int(degrees), Image.BICUBIC, True)
+    return i.rotate(int(degrees), Image.Resampling.BICUBIC, True)
 
 
 def apply_filter(i, f):
@@ -237,8 +239,8 @@ def apply_filter(i, f):
 
 basic_ops = {
     "crop": crop,
-    "flip_horizontal": lambda i: i.transpose(Image.FLIP_LEFT_RIGHT),
-    "flip_vertical": lambda i: i.transpose(Image.FLIP_TOP_BOTTOM),
+    "flip_horizontal": lambda i: i.transpose(Image.Transpose.FLIP_LEFT_RIGHT),
+    "flip_vertical": lambda i: i.transpose(Image.Transpose.FLIP_TOP_BOTTOM),
     "grayscale": lambda i: i.convert("L"),
     "resize": resize,
     "rotate": rotate,
@@ -260,7 +262,7 @@ basic_ops = {
 
 
 def harvest_images(path, context):
-    log.debug("process_images: harvest %r", path)
+    log.debug("[image_process] harvesting %r", path)
     # Set default value for 'IMAGE_PROCESS_DIR'.
     if "IMAGE_PROCESS_DIR" not in context:
         context["IMAGE_PROCESS_DIR"] = "derivatives"
@@ -373,7 +375,7 @@ def compute_paths(img, settings, derivative):
         posixpath.dirname(img["src"]), pathname2url(derivative_path)
     )
 
-    if PELICAN_MAJOR_VERSION < 4:
+    if pelican_version != "unknown" and int(pelican_version.split(".")[0]) < 4:
         file_paths = settings["filenames"]
     else:
         file_paths = settings["static_content"]
@@ -412,6 +414,12 @@ def compute_paths(img, settings, derivative):
 
 def process_img_tag(img, settings, derivative):
     path = compute_paths(img, settings, derivative)
+    if not is_img_identifiable(path.source):
+        log.warn(
+            "[image_process] Skipping image %s that could not be identified by Pillow",
+            path.source,
+        )
+        return
     process = settings["IMAGE_PROCESS"][derivative]
 
     img["src"] = posixpath.join(path.base_url, path.filename)
@@ -423,8 +431,22 @@ def process_img_tag(img, settings, derivative):
     process_image((path.source, destination, process), settings)
 
 
+def is_img_identifiable(img_filepath):
+    try:
+        Image.open(img_filepath)
+        return True
+    except (FileNotFoundError, UnidentifiedImageError):
+        return False
+
+
 def build_srcset(img, settings, derivative):
     path = compute_paths(img, settings, derivative)
+    if not is_img_identifiable(path.source):
+        log.warn(
+            "[image_process] Skipping image %s that could not be identified by Pillow",
+            path.source,
+        )
+        return
     process = settings["IMAGE_PROCESS"][derivative]
 
     default = process["default"]
@@ -432,7 +454,7 @@ def build_srcset(img, settings, derivative):
         breakpoints = {i for i, _ in process["srcset"]}
         if default not in breakpoints:
             log.error(
-                'image_process: srcset "%s" does not define default "%s"',
+                '[image_process] srcset "%s" does not define default "%s"',
                 derivative,
                 default,
             )
@@ -672,7 +694,7 @@ def process_image(image, settings):
     image[1] = unquote(image[1])
     # image[2] is the transformation
 
-    log.debug("image_process: {} -> {}".format(image[0], image[1]))
+    log.debug("[image_process] {} -> {}".format(image[0], image[1]))
 
     os.makedirs(os.path.dirname(image[1]), exist_ok=True)
 
