@@ -10,7 +10,9 @@ import pytest
 
 from pelican.plugins.image_process import (
     ExifTool,
+    compute_paths,
     harvest_images_in_fragment,
+    is_img_identifiable,
     process_image,
 )
 
@@ -87,6 +89,7 @@ def test_all_transforms(tmp_path, transform_id, transform_params, image_path):
 
     transformed = Image.open(destination_path)
     expected = Image.open(expected_path)
+    # Image.getbbox() returns None if there are only black pixels in the image:
     image_diff = ImageChops.difference(transformed, expected).getbbox()
     assert image_diff is None
 
@@ -115,6 +118,11 @@ def test_all_transforms(tmp_path, transform_id, transform_params, image_path):
     ],
 )
 def test_path_normalization(mocker, orig_src, orig_img, new_src, new_img):
+    # Allow non-existing images to be processed:
+    mocker.patch(
+        "pelican.plugins.image_process.image_process.is_img_identifiable",
+        lambda img_filepath: True,
+    )
     # Silence image transforms.
     process = mocker.patch("pelican.plugins.image_process.image_process.process_image")
 
@@ -431,6 +439,11 @@ COMPLEX_TRANSFORMS = {
     ],
 )
 def test_picture_generation(mocker, orig_tag, new_tag, call_args):
+    # Allow non-existing images to be processed:
+    mocker.patch(
+        "pelican.plugins.image_process.image_process.is_img_identifiable",
+        lambda img_filepath: True,
+    )
     process = mocker.patch("pelican.plugins.image_process.image_process.process_image")
 
     settings = get_settings(
@@ -543,3 +556,36 @@ def test_copy_exif_tags(tmp_path, image_path, copy_tags):
             assert expected_tags[tag] == actual_tags[tag]
         else:
             assert tag not in actual_tags.keys()
+
+
+def test_is_img_identifiable():
+    for test_image in TEST_IMAGES:
+        assert is_img_identifiable(test_image)
+
+    assert not is_img_identifiable("image/that/does/not/exist.png")
+
+    assert not is_img_identifiable(TEST_DATA.joinpath("folded_puzzle.png"))
+    assert not is_img_identifiable(TEST_DATA.joinpath("minimal.svg"))
+
+    img = {"src": "https://upload.wikimedia.org/wikipedia/commons/3/34/Exemple.png"}
+    settings = get_settings(IMAGE_PROCESS_DIR="derivatives")
+    path = compute_paths(img, settings, derivative="thumb")
+    assert not is_img_identifiable(path.source)
+
+
+def generate_test_images():
+    settings = get_settings()
+    image_count = 0
+    for image_path in TEST_IMAGES:
+        for transform_id, transform_params in SINGLE_TRANSFORMS.items():
+            process_image(
+                (
+                    str(image_path),
+                    str(TRANSFORM_RESULTS.joinpath(transform_id, image_path.name)),
+                    transform_params,
+                ),
+                settings,
+            )
+            image_count += 1
+
+    print(f"{image_count} test images generated!")
